==> Wikibase-REL1_35-56582b4.tar.gz: Wikibase/repo/maintenance/dumpRdf.php <==
<?php

namespace Wikibase\Repo\Maintenance;

use MediaWiki\MediaWikiServices;
use SiteLookup;
use Wikibase\DataModel\Services\Entity\EntityPrefetcher;
use Wikibase\DataModel\Services\EntityId\EntityIdPager;
use Wikibase\DataModel\Services\Lookup\PropertyDataTypeLookup;
use Wikibase\Lib\Store\EntityRevisionLookup;
use Wikibase\Lib\Store\EntityTitleLookup;
use Wikibase\Repo\Dumpers\DumpGenerator;
use Wikibase\Repo\Dumpers\RdfDumpGenerator;
use Wikibase\Repo\Rdf\EntityRdfBuilderFactory;
use Wikibase\Repo\Rdf\RdfVocabulary;
use Wikibase\Repo\Rdf\ValueSnakRdfBuilderFactory;
use Wikibase\Repo\Store\Sql\SqlEntityIdPagerFactory;
use Wikibase\Repo\WikibaseRepo;
use Wikimedia\Purtle\BNodeLabeler;

require_once __DIR__ . '/DumpEntities.php';

/**
 * @license GPL-2.0-or-later
 * @author Stas Malyshev
 * @author Addshore
 */
class DumpRdf extends DumpEntities {

	/**
	 * @var EntityRevisionLookup
	 */
	private $revisionLookup;

	/**
	 * @var EntityPrefetcher
	 */
	private $entityPrefetcher;

	/**
	 * @var SiteLookup
	 */
	private $siteLookup;

	/**
	 * @var PropertyDataTypeLookup
	 */
	private $propertyDatatypeLookup;

	/**
	 * @var ValueSnakRdfBuilderFactory
	 */
	private $valueSnakRdfBuilderFactory;

	/**
	 * @var EntityRdfBuilderFactory
	 */
	private $entityRdfBuilderFactory;

	/**
	 * @var RdfVocabulary
	 */
	private $rdfVocabulary;

	/**
	 * @var bool
	 */
	private $hasHadServicesSet = false;

	/**
	 * @var EntityTitleLookup
	 */
	private $titleLookup;

	public function __construct() {
		parent::__construct();
		$this->addOption( 'format', 'Set the dump format, such as "nt" or "ttl". Defaults to "ttl".', false, true );
		$this->addOption(
			'flavor',
			'Set the flavor to produce. Can be either "full-dump" or "truthy-dump". Defaults to "full-dump".',
			false,
			true
		);
		$this->addOption( 'redirect-only', 'Whether to only dump information about redirects.', false, false );
		$this->addOption( 'part-id', 'Unique identifier for this part of multi-part dump, to be used for marking bnodes.', false, true );
	}

	public function setServices(
		SqlEntityIdPagerFactory $sqlEntityIdPagerFactory,
		array $existingEntityTypes,
		array $entityTypesWithoutRdfOutput,
		EntityPrefetcher $entityPrefetcher,
		SiteLookup $siteLookup,
		PropertyDataTypeLookup $propertyDataTypeLookup,
		ValueSnakRdfBuilderFactory $valueSnakRdfBuilderFactory,
		EntityRdfBuilderFactory $entityRdfBuilderFactory,
		EntityRevisionLookup $entityRevisionLookup,
		RdfVocabulary $rdfVocabulary,
		$titleLookup
	) {
		parent::setDumpEntitiesServices(
			$sqlEntityIdPagerFactory,
			$existingEntityTypes,
			$entityTypesWithoutRdfOutput
		);
		$this->entityPrefetcher = $entityPrefetcher;
		$this->siteLookup = $siteLookup;
		$this->propertyDatatypeLookup = $propertyDataTypeLookup;
		$this->valueSnakRdfBuilderFactory = $valueSnakRdfBuilderFactory;
		$this->entityRdfBuilderFactory = $entityRdfBuilderFactory;
		$this->revisionLookup = $entityRevisionLookup;
		$this->rdfVocabulary = $rdfVocabulary;
		$this->titleLookup = $titleLookup;
		$this->hasHadServicesSet = true;
	}

	public function execute() {
		if ( !$this->hasHadServicesSet ) {
			$wikibaseRepo = WikibaseRepo::getDefaultInstance();
			$sqlEntityIdPagerFactory = new SqlEntityIdPagerFactory(
				$wikibaseRepo->getEntityNamespaceLookup(),
				$wikibaseRepo->getEntityIdLookup(),
				MediaWikiServices::getInstance()->getLinkCache()
			);

			$this->setServices(
				$sqlEntityIdPagerFactory,
				$wikibaseRepo->getEnabledEntityTypes(),
				$wikibaseRepo->getSettings()->getSetting( 'entityTypesWithoutRdfOutput' ),
				$wikibaseRepo->getStore()->getEntityPrefetcher(),
				$wikibaseRepo->getSiteLookup(),
				$wikibaseRepo->getPropertyDataTypeLookup(),
				$wikibaseRepo->getValueSnakRdfBuilderFactory(),
				$wikibaseRepo->getEntityRdfBuilderFactory(),
				$wikibaseRepo->getEntityRevisionLookup( $this->getEntityRevisionLookupCacheMode() ),
				$wikibaseRepo->getRdfVocabulary(),
				$wikibaseRepo->getEntityContentFactory()
			);
		}
		parent::execute();
	}

	/**
	 * Returns one of the EntityIdPager::XXX_REDIRECTS constants.
	 *
	 * @return mixed a EntityIdPager::XXX_REDIRECTS constant
	 */
	protected function getRedirectMode() {
		$redirectOnly = $this->getOption( 'redirect-only', false );

		if ( $redirectOnly ) {
			return EntityIdPager::ONLY_REDIRECTS;
		} else {
			return EntityIdPager::INCLUDE_REDIRECTS;
		}
	}

	/**
	 * Create concrete dumper instance
	 *
	 * @param resource $output
	 *
	 * @return DumpGenerator
	 */
	protected function createDumper( $output ) {
		$flavor = $this->getOption( 'flavor', 'full-dump' );
		if ( !in_array( $flavor, [ 'full-dump', 'truthy-dump' ] ) ) {
			$this->fatalError( 'Invalid flavor: ' . $flavor );
		}

		$labeler = null;
		$partId = $this->getOption( 'part-id' );
		if ( $partId ) {
			$labeler = new BNodeLabeler( "genid{$partId}-" );
		}

		if ( $this->getOption( 'sharding-factor', 1 ) !== 1 ) {
			$shard = $this->getOption( 'shard', 0 );
			if ( !$labeler ) {
				// Mark this shard's bnodes with shard ID if not told otherwise
				$labeler = new BNodeLabeler( "genid{$shard}-" );
			}
		}

		return RdfDumpGenerator::createDumpGenerator(
			$this->getOption( 'format', 'ttl' ),
			$output,
			$flavor,
			$this->siteLookup->getSites(),
			$this->revisionLookup,
			$this->propertyDatatypeLookup,
			$this->valueSnakRdfBuilderFactory,
			$this->entityRdfBuilderFactory,
			$this->entityPrefetcher,
			$this->rdfVocabulary,
			$this->titleLookup,
			$labeler
		);
	}

}

$maintClass = DumpRdf::class;
require_once RUN_MAINTENANCE_IF_MAIN;

==> Wikibase-REL1_38-132412b.tar.gz: Wikibase/repo/maintenance/dumpRdf.php <==
<?php

declare( strict_types = 1 );

namespace Wikibase\Repo\Maintenance;

use MediaWiki\MediaWikiServices;
use Wikibase\DataModel\Services\Entity\EntityPrefetcher;
use Wikibase\DataModel\Services\EntityId\EntityIdPager;
use Wikibase\Lib\Store\EntityRevisionLookup;
use Wikibase\Repo\Dumpers\DumpGenerator;
use Wikibase\Repo\Dumpers\RdfDumpGenerator;
use Wikibase\Repo\Rdf\RdfBuilderFactory;
use Wikibase\Repo\Rdf\UnknownFlavorException;
use Wikibase\Repo\Store\Sql\SqlEntityIdPagerFactory;
use Wikibase\Repo\WikibaseRepo;
use Wikimedia\Purtle\BNodeLabeler;

require_once __DIR__ . '/DumpEntities.php';

/**
 * @license GPL-2.0-or-later
 * @author Stas Malyshev
 * @author Addshore
 */
class DumpRdf extends DumpEntities {

	/**
	 * @var EntityRevisionLookup
	 */
	private $revisionLookup;

	/**
	 * @var EntityPrefetcher
	 */
	private $entityPrefetcher;

	/**
	 * @var bool
	 */
	private $hasHadServicesSet = false;

	/**
	 * @var RdfBuilderFactory
	 */
	private $rdfBuilderFactory;

	public function __construct() {
		parent::__construct();
		$this->addOption( 'format', 'Set the dump format, such as "nt" or "ttl". Defaults to "ttl".', false, true );
		$this->addOption(
			'flavor',
			'Set the flavor to produce. Can be either "full-dump" or "truthy-dump". Defaults to "full-dump".',
			false,
			true
		);
		$this->addOption( 'redirect-only', 'Whether to only dump information about redirects.', false, false );
		$this->addOption( 'part-id', 'Unique identifier for this part of multi-part dump, to be used for marking bnodes.', false, true );
	}

	public function setServices(
		SqlEntityIdPagerFactory $sqlEntityIdPagerFactory,
		array $existingEntityTypes,
		array $entityTypesWithoutRdfOutput,
		EntityPrefetcher $entityPrefetcher,
		EntityRevisionLookup $entityRevisionLookup,
		RdfBuilderFactory $rdfBuilderFactory
	): void {
		parent::setDumpEntitiesServices(
			$sqlEntityIdPagerFactory,
			$existingEntityTypes,
			$entityTypesWithoutRdfOutput
		);
		$this->entityPrefetcher = $entityPrefetcher;
		$this->revisionLookup = $entityRevisionLookup;
		$this->hasHadServicesSet = true;
		$this->rdfBuilderFactory = $rdfBuilderFactory;
	}

	public function execute(): void {
		if ( !$this->hasHadServicesSet ) {
			$mwServices = MediaWikiServices::getInstance();

			$sqlEntityIdPagerFactory = new SqlEntityIdPagerFactory(
				WikibaseRepo::getEntityNamespaceLookup( $mwServices ),
				WikibaseRepo::getEntityIdLookup( $mwServices ),
				WikibaseRepo::getRepoDomainDbFactory( $mwServices )->newRepoDb(),
				$mwServices->getLinkCache()
			);
			$store = WikibaseRepo::getStore( $mwServices );

			$this->setServices(
				$sqlEntityIdPagerFactory,
				WikibaseRepo::getEnabledEntityTypes( $mwServices ),
				WikibaseRepo::getSettings( $mwServices )
					->getSetting( 'entityTypesWithoutRdfOutput' ),
				$store->getEntityPrefetcher(),
				$store->getEntityRevisionLookup( $this->getEntityRevisionLookupCacheMode() ),
				WikibaseRepo::getRdfBuilderFactory( $mwServices )
			);
		}
		parent::execute();
	}

	/**
	 * Returns one of the EntityIdPager::XXX_REDIRECTS constants.
	 *
	 * @return mixed a EntityIdPager::XXX_REDIRECTS constant
	 */
	protected function getRedirectMode() {
		$redirectOnly = $this->getOption( 'redirect-only', false );

		if ( $redirectOnly ) {
			return EntityIdPager::ONLY_REDIRECTS;
		} else {
			return EntityIdPager::INCLUDE_REDIRECTS;
		}
	}

	/**
	 * Create concrete dumper instance
	 *
	 * @param resource $output
	 */
	protected function createDumper( $output ): DumpGenerator {
		$flavor = $this->getOption( 'flavor', 'full-dump' );

		$labeler = null;
		$partId = $this->getOption( 'part-id' );
		if ( $partId ) {
			$labeler = new BNodeLabeler( "genid{$partId}-" );
		}

		if ( $this->getOption( 'sharding-factor', 1 ) !== 1 ) {
			$shard = $this->getOption( 'shard', 0 );
			if ( !$labeler ) {
				// Mark this shard's bnodes with shard ID if not told otherwise
				$labeler = new BNodeLabeler( "genid{$shard}-" );
			}
		}

		try {
			return RdfDumpGenerator::createDumpGenerator(
				$this->getOption( 'format', 'ttl' ),
				$output,
				$flavor,
				$this->revisionLookup,
				$this->entityPrefetcher,
				$labeler,
				$this->rdfBuilderFactory
			);
		} catch ( UnknownFlavorException $e ) {
			$this->fatalError( $e->getMessage() );
		}
	}

	protected function getDumpType(): string {
		return "RDF";
	}
}

$maintClass = DumpRdf::class;
require_once RUN_MAINTENANCE_IF_MAIN;
